@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.763';
+our $VERSION = '1.767';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -161,8 +161,8 @@ sub __copy_orig_list {
                 $_ = $self->{empty} if ! length $_;
             }
             if ( $self->{color} ) {
-                s/\x{feff}//g;
-                s/\e\[[\d;]*m/\x{feff}/g;
+                s/${\PH}//g;
+                s/${\SGR_ES}/${\PH}/g;
             }
             s/\t/ /g;
             s/\v+/\ \ /g;
@@ -803,11 +803,16 @@ sub __prepare_footer_line {
 
 sub __set_cell {
     my ( $self, $list_idx ) = @_;
-    LOOP: for my $i ( 0 .. $#{$self->{rc2idx}} ) {
-        for my $j ( 0 .. $#{$self->{rc2idx}[$i]} ) {
-            if ( $list_idx == $self->{rc2idx}[$i][$j] ) {
-                $self->{pos} = [ $i, $j ];
-                last LOOP;
+    if ( $self->{current_layout} == 2 ) {
+        $self->{pos} = [ $list_idx, 0 ];
+    }
+    else {
+        LOOP: for my $i ( 0 .. $#{$self->{rc2idx}} ) {
+            for my $j ( 0 .. $#{$self->{rc2idx}[$i]} ) {
+                if ( $list_idx == $self->{rc2idx}[$i][$j] ) {
+                    $self->{pos} = [ $i, $j ];
+                    last LOOP;
+                }
             }
         }
     }
@@ -908,11 +913,11 @@ sub __prepare_cell {
             if ( $emphasised ) {
                 if ( $is_current_pos && $self->{color} == 1 ) {
                     # no color for the selected cell if color == 1
-                    $str =~ s/(\e\[[\d;]*m)//g;
+                    $str =~ s/${\SGR_ES}//g;
                 }
                 else {
                     # keep marked cells marked after color escapes
-                    $str =~ s/(\e\[[\d;]*m)/${1}$emphasised/g;
+                    $str =~ s/(${\SGR_ES})/${1}$emphasised/g;
                 }
                 $str = $emphasised . $str;
             }
@@ -933,14 +938,14 @@ sub __prepare_cell {
             my @color;
             if ( ! $self->{orig_list}[$idx] ) {
                 if ( ! defined $self->{orig_list}[$idx] ) {
-                    @color = $self->{undef} =~ /(\e\[[\d;]*m)/g;
+                    @color = $self->{undef} =~ /(${\SGR_ES})/g;
                 }
                 elsif ( ! length $self->{orig_list}[$idx] ) {
-                    @color = $self->{empty} =~ /(\e\[[\d;]*m)/g;
+                    @color = $self->{empty} =~ /(${\SGR_ES})/g;
                 }
             }
             else {
-                @color = $self->{orig_list}[$idx] =~ /(\e\[[\d;]*m)/g;
+                @color = $self->{orig_list}[$idx] =~ /(${\SGR_ES})/g;
             }
             if ( $emphasised ) {
                 for ( @color ) {
@@ -951,11 +956,11 @@ sub __prepare_cell {
                 if ( $is_current_pos && $self->{color} == 1 ) {
                     # no color for the selected cell if color == 1
                     @color = ();
-                    $str =~ s/\x{feff}//g;
+                    $str =~ s/${\PH}//g;
                 }
             }
             if ( @color ) {
-                $str =~ s/\x{feff}/shift @color/ge;
+                $str =~ s/${\PH}/shift @color/ge;
                 if ( ! $emphasised ) {
                     $str .= normal();
                 }
@@ -1275,7 +1280,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.763
+Version 1.767
 
 =cut
 
@@ -1675,12 +1680,11 @@ I<margin> expects a reference to an array with four elements in the following or
 
 - right margin (number of terminal columns)
 
-- botton margin (number of terminal lines)
+- bottom margin (number of terminal lines)
 
 - left margin (number of terminal columns)
 
-I<margin> does not affect the I<info> and I<prompt> string. To add margins to the I<info> and I<prompt> string see
-I<tabs_info> and I<tabs_prompt>.
+See also L</tabs_info> and L</tabs_prompt>.
 
 Allowed values: 0 or greater. Elements beyond the fourth are ignored.
 
@@ -1934,7 +1938,7 @@ The escape sequences to enable the I<mouse> mode are always hardcoded.
 =head2 Other environment variables
 
 If the environment variable C<TC_RESET_AUTO_UP> existed when calling C<choose>: C<TC_RESET_AUTO_UP> is set to C<0> if
-the C<LINE_FEED>/C<CARRIAGE_RETURN> key was the only key pressed and C<TC_RESET_AUTO_UP> is set ot C<1> if other keys
+the C<LINE_FEED>/C<CARRIAGE_RETURN> key was the only key pressed and C<TC_RESET_AUTO_UP> is set to C<1> if other keys
 than C<LINE_FEED>/C<CARRIAGE_RETURN> were also pressed.
 
 =head2 MSWin32
