@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.765';
+our $VERSION = '1.767';
 
 use Exporter qw( import );
 
@@ -72,8 +72,8 @@ sub table_char_width { [
 [   0x829,    0x82d, 0],
 [   0x82e,    0x858, 1],
 [   0x859,    0x85b, 0],
-[   0x85c,    0x897, 1],
-[   0x898,    0x89f, 0],
+[   0x85c,    0x896, 1],
+[   0x897,    0x89f, 0],
 [   0x8a0,    0x8c9, 1],
 [   0x8ca,    0x8e1, 0],
 [   0x8e2,    0x8e2, 1],
@@ -379,11 +379,15 @@ sub table_char_width { [
 [  0x25fd,   0x25fe, 2],
 [  0x25ff,   0x2613, 1],
 [  0x2614,   0x2615, 2],
-[  0x2616,   0x2647, 1],
+[  0x2616,   0x262f, 1],
+[  0x2630,   0x2637, 2],
+[  0x2638,   0x2647, 1],
 [  0x2648,   0x2653, 2],
 [  0x2654,   0x267e, 1],
 [  0x267f,   0x267f, 2],
-[  0x2680,   0x2692, 1],
+[  0x2680,   0x2689, 1],
+[  0x268a,   0x268f, 2],
+[  0x2690,   0x2692, 1],
 [  0x2693,   0x2693, 2],
 [  0x2694,   0x26a0, 1],
 [  0x26a1,   0x26a1, 2],
@@ -459,15 +463,13 @@ sub table_char_width { [
 [  0x3130,   0x3130, 1],
 [  0x3131,   0x318e, 2],
 [  0x318f,   0x318f, 1],
-[  0x3190,   0x31e3, 2],
-[  0x31e4,   0x31ee, 1],
+[  0x3190,   0x31e5, 2],
+[  0x31e6,   0x31ee, 1],
 [  0x31ef,   0x321e, 2],
 [  0x321f,   0x321f, 1],
 [  0x3220,   0x3247, 2],
 [  0x3248,   0x324f, 1],
-[  0x3250,   0x4dbf, 2],
-[  0x4dc0,   0x4dff, 1],
-[  0x4e00,   0xa48c, 2],
+[  0x3250,   0xa48c, 2],
 [  0xa48d,   0xa48f, 1],
 [  0xa490,   0xa4c6, 2],
 [  0xa4c7,   0xa66e, 1],
@@ -589,10 +591,12 @@ sub table_char_width { [
 [ 0x10ae5,  0x10ae6, 0],
 [ 0x10ae7,  0x10d23, 1],
 [ 0x10d24,  0x10d27, 0],
-[ 0x10d28,  0x10eaa, 1],
+[ 0x10d28,  0x10d68, 1],
+[ 0x10d69,  0x10d6d, 0],
+[ 0x10d6e,  0x10eaa, 1],
 [ 0x10eab,  0x10eac, 0],
-[ 0x10ead,  0x10efc, 1],
-[ 0x10efd,  0x10eff, 0],
+[ 0x10ead,  0x10efb, 1],
+[ 0x10efc,  0x10eff, 0],
 [ 0x10f00,  0x10f45, 1],
 [ 0x10f46,  0x10f50, 0],
 [ 0x10f51,  0x10f81, 1],
@@ -657,7 +661,17 @@ sub table_char_width { [
 [ 0x11366,  0x1136c, 0],
 [ 0x1136d,  0x1136f, 1],
 [ 0x11370,  0x11374, 0],
-[ 0x11375,  0x11437, 1],
+[ 0x11375,  0x113ba, 1],
+[ 0x113bb,  0x113c0, 0],
+[ 0x113c1,  0x113cd, 1],
+[ 0x113ce,  0x113ce, 0],
+[ 0x113cf,  0x113cf, 1],
+[ 0x113d0,  0x113d0, 0],
+[ 0x113d1,  0x113d1, 1],
+[ 0x113d2,  0x113d2, 0],
+[ 0x113d3,  0x113e0, 1],
+[ 0x113e1,  0x113e2, 0],
+[ 0x113e3,  0x11437, 1],
 [ 0x11438,  0x1143f, 0],
 [ 0x11440,  0x11441, 1],
 [ 0x11442,  0x11444, 0],
@@ -696,7 +710,9 @@ sub table_char_width { [
 [ 0x116b6,  0x116b6, 1],
 [ 0x116b7,  0x116b7, 0],
 [ 0x116b8,  0x1171c, 1],
-[ 0x1171d,  0x1171f, 0],
+[ 0x1171d,  0x1171d, 0],
+[ 0x1171e,  0x1171e, 1],
+[ 0x1171f,  0x1171f, 0],
 [ 0x11720,  0x11721, 1],
 [ 0x11722,  0x11725, 0],
 [ 0x11726,  0x11726, 1],
@@ -773,11 +789,17 @@ sub table_char_width { [
 [ 0x11f40,  0x11f40, 0],
 [ 0x11f41,  0x11f41, 1],
 [ 0x11f42,  0x11f42, 0],
-[ 0x11f43,  0x1342f, 1],
+[ 0x11f43,  0x11f59, 1],
+[ 0x11f5a,  0x11f5a, 0],
+[ 0x11f5b,  0x1342f, 1],
 [ 0x13430,  0x13440, 0],
 [ 0x13441,  0x13446, 1],
 [ 0x13447,  0x13455, 0],
-[ 0x13456,  0x16aef, 1],
+[ 0x13456,  0x1611d, 1],
+[ 0x1611e,  0x16129, 0],
+[ 0x1612a,  0x1612c, 1],
+[ 0x1612d,  0x1612f, 0],
+[ 0x16130,  0x16aef, 1],
 [ 0x16af0,  0x16af4, 0],
 [ 0x16af5,  0x16b2f, 1],
 [ 0x16b30,  0x16b36, 0],
@@ -794,8 +816,8 @@ sub table_char_width { [
 [ 0x17000,  0x187f7, 2],
 [ 0x187f8,  0x187ff, 1],
 [ 0x18800,  0x18cd5, 2],
-[ 0x18cd6,  0x18cff, 1],
-[ 0x18d00,  0x18d08, 2],
+[ 0x18cd6,  0x18cfe, 1],
+[ 0x18cff,  0x18d08, 2],
 [ 0x18d09,  0x1afef, 1],
 [ 0x1aff0,  0x1aff3, 2],
 [ 0x1aff4,  0x1aff4, 1],
@@ -832,7 +854,11 @@ sub table_char_width { [
 [ 0x1d1aa,  0x1d1ad, 0],
 [ 0x1d1ae,  0x1d241, 1],
 [ 0x1d242,  0x1d244, 0],
-[ 0x1d245,  0x1d9ff, 1],
+[ 0x1d245,  0x1d2ff, 1],
+[ 0x1d300,  0x1d356, 2],
+[ 0x1d357,  0x1d35f, 1],
+[ 0x1d360,  0x1d376, 2],
+[ 0x1d377,  0x1d9ff, 1],
 [ 0x1da00,  0x1da36, 0],
 [ 0x1da37,  0x1da3a, 1],
 [ 0x1da3b,  0x1da6c, 0],
@@ -864,7 +890,9 @@ sub table_char_width { [
 [ 0x1e2ec,  0x1e2ef, 0],
 [ 0x1e2f0,  0x1e4eb, 1],
 [ 0x1e4ec,  0x1e4ef, 0],
-[ 0x1e4f0,  0x1e8cf, 1],
+[ 0x1e4f0,  0x1e5ed, 1],
+[ 0x1e5ee,  0x1e5ef, 0],
+[ 0x1e5f0,  0x1e8cf, 1],
 [ 0x1e8d0,  0x1e8d6, 0],
 [ 0x1e8d7,  0x1e943, 1],
 [ 0x1e944,  0x1e94a, 0],
@@ -949,16 +977,14 @@ sub table_char_width { [
 [ 0x1fa00,  0x1fa6f, 1],
 [ 0x1fa70,  0x1fa7c, 2],
 [ 0x1fa7d,  0x1fa7f, 1],
-[ 0x1fa80,  0x1fa88, 2],
-[ 0x1fa89,  0x1fa8f, 1],
-[ 0x1fa90,  0x1fabd, 2],
-[ 0x1fabe,  0x1fabe, 1],
-[ 0x1fabf,  0x1fac5, 2],
-[ 0x1fac6,  0x1facd, 1],
-[ 0x1face,  0x1fadb, 2],
-[ 0x1fadc,  0x1fadf, 1],
-[ 0x1fae0,  0x1fae8, 2],
-[ 0x1fae9,  0x1faef, 1],
+[ 0x1fa80,  0x1fa89, 2],
+[ 0x1fa8a,  0x1fa8e, 1],
+[ 0x1fa8f,  0x1fac6, 2],
+[ 0x1fac7,  0x1facd, 1],
+[ 0x1face,  0x1fadc, 2],
+[ 0x1fadd,  0x1fade, 1],
+[ 0x1fadf,  0x1fae9, 2],
+[ 0x1faea,  0x1faef, 1],
 [ 0x1faf0,  0x1faf8, 2],
 [ 0x1faf9,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
